@@ -346,7 +346,7 @@ pre_get_xml (GDataParsable *parsable, GString *xml_string)
 	}
 
 	if (priv->value_string != NULL)
-		g_string_append_printf (xml_string, " valueString='%s'", priv->value_string);
+		gdata_parser_string_append_escaped (xml_string, " valueString='", priv->value_string, "'");
 }
 
 static void
@@ -368,7 +368,7 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
 /**
  * gdata_gd_when_new:
  * @start_time: when the event starts or (for zero-duration events) when it occurs
- * @end_time: when the event ends, or %NULL
+ * @end_time: (allow-none): when the event ends, or %NULL
  * @is_date: %TRUE if @start_time and @end_time specify dates rather than times, %FALSE otherwise
  *
  * Creates a new #GDataGDWhen. More information is available in the <ulink type="http"
@@ -429,7 +429,7 @@ gdata_gd_when_compare (const GDataGDWhen *a, const GDataGDWhen *b)
 /**
  * gdata_gd_when_get_start_time:
  * @self: a #GDataGDWhen
- * @start_time: return location for the start time
+ * @start_time: (out caller-allocates): return location for the start time
  *
  * Gets the #GDataGDWhen:start-time property and returns it in @start_time.
  *
@@ -465,7 +465,7 @@ gdata_gd_when_set_start_time (GDataGDWhen *self, GTimeVal *start_time)
 /**
  * gdata_gd_when_get_end_time:
  * @self: a #GDataGDWhen
- * @end_time: return location for the end time
+ * @end_time: (out caller-allocates): return location for the end time
  *
  * Gets the #GDataGDWhen:end-time property and returns it in @end_time.
  *
@@ -484,7 +484,7 @@ gdata_gd_when_get_end_time (GDataGDWhen *self, GTimeVal *end_time)
 /**
  * gdata_gd_when_set_end_time:
  * @self: a #GDataGDWhen
- * @end_time: the new end time, or %NULL
+ * @end_time: (allow-none): the new end time, or %NULL
  *
  * Sets the #GDataGDWhen:end-time property to @end_time.
  *
@@ -560,7 +560,7 @@ gdata_gd_when_get_value_string (GDataGDWhen *self)
 /**
  * gdata_gd_when_set_value_string:
  * @self: a #GDataGDWhen
- * @value_string: the new value string, or %NULL
+ * @value_string: (allow-none): the new value string, or %NULL
  *
  * Sets the #GDataGDWhen:value-string property to @value_string.
  *
@@ -584,7 +584,7 @@ gdata_gd_when_set_value_string (GDataGDWhen *self, const gchar *value_string)
  *
  * Returns a list of the #GDataGDReminder<!-- -->s which are associated with this #GDataGDWhen.
  *
- * Return value: a #GList of #GDataGDReminder<!-- -->s, or %NULL
+ * Return value: (element-type GData.GDReminder) (transfer none): a #GList of #GDataGDReminder<!-- -->s, or %NULL
  *
  * Since: 0.4.0
  **/
